
[![PyPI version](https://badge.fury.io/py/skfeature-chappers.svg)](https://badge.fury.io/py/skfeature-chappers) [![codecov](https://codecov.io/gh/charliec443/scikit-feature/branch/master/graph/badge.svg?token=B7RQ11SAAN)](https://codecov.io/gh/charliec443/scikit-feature)

`scikit-feature` is an open-source (GNU General Public License v2.0) feature selection repository in Python developed by Data Mining and Machine Learning Lab at Arizona State University. 

It serves as a platform for facilitating feature selection application, research and comparative study. It is designed to share widely used feature selection algorithms developed in the feature selection research, and offer convenience for researchers and practitioners to perform empirical evaluation in developing new feature selection algorithms.

This is may or may not be a temporary fork of the original repository as development seems to have stalled and various modules have be depreciated due to updates to `scikit-learn`. I will see if should get reintegrated back into the original project if it ever gets revived again. 

**Forked project information**

*  Project site - https://github.com/chappers/scikit-feature

**Original `scikit-feature` project information**

*  Project site - https://github.com/jundongl/scikit-feature
*  Documentation - http://featureselection.asu.edu/

Installation
============

# From Sources

*  Unpack the source package somewhere
*  Run `pip install -e .` from the source distribution's top level folder

# From pip

```sh
pip install skfeature-chappers
```

